
# Rafflesia - stratified sampling

# This script looks at the advantages of a stratified design when Rafflesia
#   are not distributed evenly over the study area.
# See Rafflesia_stratified_sampling.pdf for background information and a
#   plot of the study area.

# The population
# ==============
# The first 160 sites have high numbers, the last 240 sites low numbers.
set.seed(123)
( truePop <- c(rpois(160,10), rpois(240,1)) )
(total <- sum(truePop)) # no. of Rafflesia in the population
sum(truePop[1:160])   # in the high density area...
sum(truePop[161:400]) # ...and in the low density area

# A. Unstratified simple random sampling:
# =======================================
( x <- sample(truePop, 20) )
mean(x)       # estimated average number of Rafflesia per plot
mean(x) * 400 # estimated number of Rafflesia in the whole area (400 plots)

# Do thousands of samples
# -----------------------
total.hatU <- numeric(1000)

for(i in 1:1000) {
  x <- sample(truePop, 20)
  total.hatU[i] <- mean(x) * 400
}
head(total.hatU)
mean(total.hatU)
total
hist(total.hatU)
abline(v = total, col='blue')
abline(v = mean(total.hatU), col='red')


# B. Stratified sampling
#   Number of plots proportional to area
# ======================================
n1 <- 8  # from high density area
n2 <- 12 # from low density area

( x1 <- sample(truePop[1:160], n1) )
( x2 <- sample(truePop[161:400], n2) )
mean(x1)  # average per plot in high density area...
mean(x2)  # ... and in low density area.
mean(x1) * 160 + mean(x2) * 240  # Estimated total number


total.hat8.12 <- numeric(1000)

for(i in 1:1000)  {
  x1 <- sample(truePop[1:160], n1)    # sample from high density ares...
  x2 <- sample(truePop[161:400], n2)  # ...and from low density area.
  total.hat8.12[i] <- mean(x1) * 160 + mean(x2) * 240 # add estimates together
}

mean(total.hat8.12)
total
hist(total.hat8.12)
abline(v = total, col='blue')
abline(v = mean(total.hat8.12), col='red')

# C. Stratified sample
#   More plots in high density area
# =================================

# Generate 1000 samples with n1 = 13, n2 = 7.
# Put the result in an object called 'total.hat13.7' and check for bias.
# HINT: Copy-paste the code from section B and then change it.


# Compare the estimates
# =====================

# Method 1: look at histograms
# ----------------------------

par(mfrow=c(3,1))
hist(total.hatU, xlim=c(500, 3500), main="Unstratified")
abline(v=total, col='red')
hist(total.hat8.12, xlim=c(500, 3500), main="Stratified, 8 vs 12")
abline(v=total, col='red')
# Add the histogram for total.hat13.7

par(mfrow=c(1,1))

# Compare RMSE
sqrt(mean((total.hatU - total)^2))
sqrt(mean((total.hat8.12 - total)^2))
# Add the RMSE for total.hat13.7

# Do beeswarm plot
library(beeswarm)
df <- data.frame(un=total.hatU, s8.12=total.hat8.12)
# Add total.hat13.7 to the data frame.
head(df)
beeswarm(df, cex=0.5, col='blue', method='hex')
abline(h=total, col='red', lwd=3)

# D. Stratified sample
#   Even more plots in high density area!
# =======================================
# 13.7 has lowest RMSE; try even more from high density area.
# Generate 1000 samples with n1 = 17, n2 = 3.
# Put the result in an object called 'total.hat17.3' and check for bias.


# Calculate RMSE and compare with the others


# Estimate density from stratified sampling
# =========================================
n1 <- 13 # from densely populated area (stratum #1)
n2 <- 7  # from less densely populated area (stratum #2)

( x1 <- sample(truePop[1:160], n1) )
( x2 <- sample(truePop[161:400], n2) )
( d1 <- mean(x1) )  # estimated density for stratum #1
( d2 <- mean(x2) )  # ...and for stratum #2.

# Combine densities as a weighted mean of d1 and d2, with the proportions
#   of the area as the weights
w1 <- 160/400  # proportion of area in stratum #1...
w2 <- 240/400  # ...and in stratum #2
# Estimated mean density over the whole study area:
d1*w1 + d2*w2

# or do it in one line:
#      v proportion of area in stratum #1
d1*(160/400) + d2*(240/400)
#                     ^ proportion of area in #2


# What happens if we do stratified sampling data collection
#  but simple random analysis?
# =========================================================
n1 <- 13
n2 <- 7

total.hat.bad <- numeric(1000)

for(i in 1:1000)  {
  x1 <- sample(truePop[1:160], n1)
  x2 <- sample(truePop[161:400], n2)
  x <- c(x1, x2)  # Combine the two samples into a single sample
  total.hat.bad[i] <- mean(x) * 400
}

mean(total.hat.bad)
total
hist(total.hat.bad, xlim=c(1500, 3500))
abline(v = total, col='blue')
abline(v = mean(total.hat.bad), col='red')
